# __version__ = "0.0.58" # 周期增加月份支持
# __version__ = "0.0.59" # 增加Indicator
# __version__ = "0.0.60" # 增加datatimetype
# __version__ = "0.0.61" # query_hisotry_n由decimal改为返回float
# # __version__ = "0.0.71" # DataTimeType -> Timing
# __version__ = "0.0.63" # 增加很多constant。例如ExecuteStrategy, IndicatorColumn等标准字段
# __version__ = "0.0.64" # 增加INTERVAL2SUBSCRIBE_TYPE。更新ks_utility到版本0.0.32
# __version__ = "0.0.65" # 增加SUBSCRIBE_TYPE2INTERVAL
# __version__ = "0.0.69" # 增加IndicatorData
# __version__ = "0.0.72" # MySubscribeType支持snapshot
# __version__ = "0.0.73" # 合并之前分支
# __version__ = "0.0.74" # get_trading_time默认返回原来交易所时区
# __version__ = "0.1.0" # 全部enum移除中文
# __version__ = "0.1.1" # 增加global_limit_rate跨线程流速控制装饰器
# __version__ = "0.1.2" # 修正global_limit_rate临时目录
# __version__ = "0.1.4" # update version
__version__ = "0.1.5" # 重构globallimit